from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Deposit(_message.Message):
    __slots__ = ["address", "coins"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, address: _Optional[str] = ..., coins: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ["deposit", "staking_share"]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    STAKING_SHARE_FIELD_NUMBER: _ClassVar[int]
    deposit: _coin_pb2.Coin
    staking_share: str
    def __init__(self, deposit: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., staking_share: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/swap/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.swap.v1 import swap_pb2 as sentinel_dot_swap_dot_v1_dot_swap__pb2
from sentinel.swap.v1 import params_pb2 as sentinel_dot_swap_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/swap/v1/querier.proto\x12\x10sentinel.swap.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bsentinel/swap/v1/swap.proto\x1a\x1dsentinel/swap/v1/params.proto\"O\n\x11QuerySwapsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"#\n\x10QuerySwapRequest\x12\x0f\n\x07tx_hash\x18\x01 \x01(\x0c\"\x14\n\x12QueryParamsRequest\"~\n\x12QuerySwapsResponse\x12+\n\x05swaps\x18\x01 \x03(\x0b\x32\x16.sentinel.swap.v1.SwapB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"?\n\x11QuerySwapResponse\x12*\n\x04swap\x18\x01 \x01(\x0b\x32\x16.sentinel.swap.v1.SwapB\x04\xc8\xde\x1f\x00\"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.sentinel.swap.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\xfd\x02\n\x0cQueryService\x12p\n\nQuerySwaps\x12#.sentinel.swap.v1.QuerySwapsRequest\x1a$.sentinel.swap.v1.QuerySwapsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/swaps\x12w\n\tQuerySwap\x12\".sentinel.swap.v1.QuerySwapRequest\x1a#.sentinel.swap.v1.QuerySwapResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/swaps/{tx_hash}\x12\x81\x01\n\x0bQueryParams\x12$.sentinel.swap.v1.QueryParamsRequest\x1a%.sentinel.swap.v1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/swap/paramsB7Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\250\342\036\000\310\341\036\000'
  _QUERYSWAPSRESPONSE.fields_by_name['swaps']._options = None
  _QUERYSWAPSRESPONSE.fields_by_name['swaps']._serialized_options = b'\310\336\037\000'
  _QUERYSWAPRESPONSE.fields_by_name['swap']._options = None
  _QUERYSWAPRESPONSE.fields_by_name['swap']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QuerySwaps']._options = None
  _QUERYSERVICE.methods_by_name['QuerySwaps']._serialized_options = b'\202\323\344\223\002\021\022\017/sentinel/swaps'
  _QUERYSERVICE.methods_by_name['QuerySwap']._options = None
  _QUERYSERVICE.methods_by_name['QuerySwap']._serialized_options = b'\202\323\344\223\002\033\022\031/sentinel/swaps/{tx_hash}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\037\022\035/sentinel/modules/swap/params'
  _QUERYSWAPSREQUEST._serialized_start=208
  _QUERYSWAPSREQUEST._serialized_end=287
  _QUERYSWAPREQUEST._serialized_start=289
  _QUERYSWAPREQUEST._serialized_end=324
  _QUERYPARAMSREQUEST._serialized_start=326
  _QUERYPARAMSREQUEST._serialized_end=346
  _QUERYSWAPSRESPONSE._serialized_start=348
  _QUERYSWAPSRESPONSE._serialized_end=474
  _QUERYSWAPRESPONSE._serialized_start=476
  _QUERYSWAPRESPONSE._serialized_end=539
  _QUERYPARAMSRESPONSE._serialized_start=541
  _QUERYPARAMSRESPONSE._serialized_end=610
  _QUERYSERVICE._serialized_start=613
  _QUERYSERVICE._serialized_end=994
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventRegister(_message.Message):
    __slots__ = ["address", "provider"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    address: str
    provider: str
    def __init__(self, address: _Optional[str] = ..., provider: _Optional[str] = ...) -> None: ...

class EventSetStatus(_message.Message):
    __slots__ = ["address", "status"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    status: _status_pb2.Status
    def __init__(self, address: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ...) -> None: ...

class EventUpdate(_message.Message):
    __slots__ = ["address", "provider"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    address: str
    provider: str
    def __init__(self, address: _Optional[str] = ..., provider: _Optional[str] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MsgRegisterRequest(_message.Message):
    __slots__ = ["description", "frm", "identity", "name", "website"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    description: str
    frm: str
    identity: str
    name: str
    website: str
    def __init__(self, frm: _Optional[str] = ..., name: _Optional[str] = ..., identity: _Optional[str] = ..., website: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class MsgRegisterResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateRequest(_message.Message):
    __slots__ = ["description", "frm", "identity", "name", "website"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    description: str
    frm: str
    identity: str
    name: str
    website: str
    def __init__(self, frm: _Optional[str] = ..., name: _Optional[str] = ..., identity: _Optional[str] = ..., website: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class MsgUpdateResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/plan/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.node.v1 import node_pb2 as sentinel_dot_node_dot_v1_dot_node__pb2
from sentinel.plan.v1 import plan_pb2 as sentinel_dot_plan_dot_v1_dot_plan__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/plan/v1/querier.proto\x12\x10sentinel.plan.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bsentinel/node/v1/node.proto\x1a\x1bsentinel/plan/v1/plan.proto\x1a\x1esentinel/types/v1/status.proto\"z\n\x11QueryPlansRequest\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x96\x01\n\x1cQueryPlansForProviderRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x1e\n\x10QueryPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"b\n\x18QueryNodesForPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"~\n\x12QueryPlansResponse\x12+\n\x05plans\x18\x01 \x03(\x0b\x32\x16.sentinel.plan.v1.PlanB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x89\x01\n\x1dQueryPlansForProviderResponse\x12+\n\x05plans\x18\x01 \x03(\x0b\x32\x16.sentinel.plan.v1.PlanB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"?\n\x11QueryPlanResponse\x12*\n\x04plan\x18\x01 \x01(\x0b\x32\x16.sentinel.plan.v1.PlanB\x04\xc8\xde\x1f\x00\"\x85\x01\n\x19QueryNodesForPlanResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xaf\x04\n\x0cQueryService\x12p\n\nQueryPlans\x12#.sentinel.plan.v1.QueryPlansRequest\x1a$.sentinel.plan.v1.QueryPlansResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/plans\x12\xa5\x01\n\x15QueryPlansForProvider\x12..sentinel.plan.v1.QueryPlansForProviderRequest\x1a/.sentinel.plan.v1.QueryPlansForProviderResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/providers/{address}/plans\x12r\n\tQueryPlan\x12\".sentinel.plan.v1.QueryPlanRequest\x1a#.sentinel.plan.v1.QueryPlanResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/sentinel/plans/{id}\x12\x90\x01\n\x11QueryNodesForPlan\x12*.sentinel.plan.v1.QueryNodesForPlanRequest\x1a+.sentinel.plan.v1.QueryNodesForPlanResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/sentinel/plans/{id}/nodesB7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\250\342\036\000\310\341\036\000'
  _QUERYPLANSRESPONSE.fields_by_name['plans']._options = None
  _QUERYPLANSRESPONSE.fields_by_name['plans']._serialized_options = b'\310\336\037\000'
  _QUERYPLANSFORPROVIDERRESPONSE.fields_by_name['plans']._options = None
  _QUERYPLANSFORPROVIDERRESPONSE.fields_by_name['plans']._serialized_options = b'\310\336\037\000'
  _QUERYPLANRESPONSE.fields_by_name['plan']._options = None
  _QUERYPLANRESPONSE.fields_by_name['plan']._serialized_options = b'\310\336\037\000'
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryPlans']._options = None
  _QUERYSERVICE.methods_by_name['QueryPlans']._serialized_options = b'\202\323\344\223\002\021\022\017/sentinel/plans'
  _QUERYSERVICE.methods_by_name['QueryPlansForProvider']._options = None
  _QUERYSERVICE.methods_by_name['QueryPlansForProvider']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/providers/{address}/plans'
  _QUERYSERVICE.methods_by_name['QueryPlan']._options = None
  _QUERYSERVICE.methods_by_name['QueryPlan']._serialized_options = b'\202\323\344\223\002\026\022\024/sentinel/plans/{id}'
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._serialized_options = b'\202\323\344\223\002\034\022\032/sentinel/plans/{id}/nodes'
  _QUERYPLANSREQUEST._serialized_start=238
  _QUERYPLANSREQUEST._serialized_end=360
  _QUERYPLANSFORPROVIDERREQUEST._serialized_start=363
  _QUERYPLANSFORPROVIDERREQUEST._serialized_end=513
  _QUERYPLANREQUEST._serialized_start=515
  _QUERYPLANREQUEST._serialized_end=545
  _QUERYNODESFORPLANREQUEST._serialized_start=547
  _QUERYNODESFORPLANREQUEST._serialized_end=645
  _QUERYPLANSRESPONSE._serialized_start=647
  _QUERYPLANSRESPONSE._serialized_end=773
  _QUERYPLANSFORPROVIDERRESPONSE._serialized_start=776
  _QUERYPLANSFORPROVIDERRESPONSE._serialized_end=913
  _QUERYPLANRESPONSE._serialized_start=915
  _QUERYPLANRESPONSE._serialized_end=978
  _QUERYNODESFORPLANRESPONSE._serialized_start=981
  _QUERYNODESFORPLANRESPONSE._serialized_end=1114
  _QUERYSERVICE._serialized_start=1117
  _QUERYSERVICE._serialized_end=1676
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgRegisterRequest(_message.Message):
    __slots__ = ["frm", "price", "provider", "remote_url"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    REMOTE_URL_FIELD_NUMBER: _ClassVar[int]
    frm: str
    price: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    provider: str
    remote_url: str
    def __init__(self, frm: _Optional[str] = ..., provider: _Optional[str] = ..., price: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., remote_url: _Optional[str] = ...) -> None: ...

class MsgRegisterResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgSetStatusRequest(_message.Message):
    __slots__ = ["frm", "status"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    frm: str
    status: _status_pb2.Status
    def __init__(self, frm: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ...) -> None: ...

class MsgSetStatusResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateRequest(_message.Message):
    __slots__ = ["frm", "price", "provider", "remote_url"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    REMOTE_URL_FIELD_NUMBER: _ClassVar[int]
    frm: str
    price: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    provider: str
    remote_url: str
    def __init__(self, frm: _Optional[str] = ..., provider: _Optional[str] = ..., price: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., remote_url: _Optional[str] = ...) -> None: ...

class MsgUpdateResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interchain_security/ccv/provider/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,interchain_security/ccv/provider/v1/tx.proto\x12#interchain_security.ccv.provider.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x19google/protobuf/any.proto\"\xa3\x01\n\x14MsgAssignConsumerKey\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\x12)\n\rprovider_addr\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12\x44\n\x0c\x63onsumer_key\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x18\xca\xb4-\x14\x63osmos.crypto.PubKey:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgAssignConsumerKeyResponse2\x99\x01\n\x03Msg\x12\x91\x01\n\x11\x41ssignConsumerKey\x12\x39.interchain_security.ccv.provider.v1.MsgAssignConsumerKey\x1a\x41.interchain_security.ccv.provider.v1.MsgAssignConsumerKeyResponseB<Z:github.com/cosmos/interchain-security/x/ccv/provider/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interchain_security.ccv.provider.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/cosmos/interchain-security/x/ccv/provider/types'
  _MSGASSIGNCONSUMERKEY.fields_by_name['provider_addr']._options = None
  _MSGASSIGNCONSUMERKEY.fields_by_name['provider_addr']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _MSGASSIGNCONSUMERKEY.fields_by_name['consumer_key']._options = None
  _MSGASSIGNCONSUMERKEY.fields_by_name['consumer_key']._serialized_options = b'\312\264-\024cosmos.crypto.PubKey'
  _MSGASSIGNCONSUMERKEY._options = None
  _MSGASSIGNCONSUMERKEY._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGASSIGNCONSUMERKEY._serialized_start=192
  _MSGASSIGNCONSUMERKEY._serialized_end=355
  _MSGASSIGNCONSUMERKEYRESPONSE._serialized_start=357
  _MSGASSIGNCONSUMERKEYRESPONSE._serialized_end=387
  _MSG._serialized_start=390
  _MSG._serialized_end=543
# @@protoc_insertion_point(module_scope)



from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NextFeeDistributionEstimate(_message.Message):
    __slots__ = ["currentHeight", "distribution_fraction", "lastHeight", "nextHeight", "toConsumer", "toProvider", "total"]
    CURRENTHEIGHT_FIELD_NUMBER: _ClassVar[int]
    DISTRIBUTION_FRACTION_FIELD_NUMBER: _ClassVar[int]
    LASTHEIGHT_FIELD_NUMBER: _ClassVar[int]
    NEXTHEIGHT_FIELD_NUMBER: _ClassVar[int]
    TOCONSUMER_FIELD_NUMBER: _ClassVar[int]
    TOPROVIDER_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    currentHeight: int
    distribution_fraction: str
    lastHeight: int
    nextHeight: int
    toConsumer: str
    toProvider: str
    total: str
    def __init__(self, currentHeight: _Optional[int] = ..., lastHeight: _Optional[int] = ..., nextHeight: _Optional[int] = ..., distribution_fraction: _Optional[str] = ..., total: _Optional[str] = ..., toProvider: _Optional[str] = ..., toConsumer: _Optional[str] = ...) -> None: ...

class QueryNextFeeDistributionEstimateRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryNextFeeDistributionEstimateResponse(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: NextFeeDistributionEstimate
    def __init__(self, data: _Optional[_Union[NextFeeDistributionEstimate, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v1/proof.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from sentinel.types.v1 import bandwidth_pb2 as sentinel_dot_types_dot_v1_dot_bandwidth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsentinel/session/v1/proof.proto\x12\x13sentinel.session.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a!sentinel/types/v1/bandwidth.proto\"\x81\x01\n\x05Proof\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x35\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x35\n\tbandwidth\x18\x03 \x01(\x0b\x32\x1c.sentinel.types.v1.BandwidthB\x04\xc8\xde\x1f\x00\x42:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v1.proof_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _PROOF.fields_by_name['duration']._options = None
  _PROOF.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000'
  _PROOF.fields_by_name['bandwidth']._options = None
  _PROOF.fields_by_name['bandwidth']._serialized_options = b'\310\336\037\000'
  _PROOF._serialized_start=146
  _PROOF._serialized_end=275
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.plan.v1 import plan_pb2 as _plan_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisPlan(_message.Message):
    __slots__ = ["nodes", "plan"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedScalarFieldContainer[str]
    plan: _plan_pb2.Plan
    def __init__(self, plan: _Optional[_Union[_plan_pb2.Plan, _Mapping]] = ..., nodes: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/swap/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/swap/v1/msg.proto\x12\x10sentinel.swap.v1\x1a\x14gogoproto/gogo.proto\"\x80\x01\n\x0eMsgSwapRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x0f\n\x07tx_hash\x18\x02 \x01(\x0c\x12\x10\n\x08receiver\x18\x03 \x01(\t\x12>\n\x06\x61mount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x11\n\x0fMsgSwapResponse2\\\n\nMsgService\x12N\n\x07MsgSwap\x12 .sentinel.swap.v1.MsgSwapRequest\x1a!.sentinel.swap.v1.MsgSwapResponseB7Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\250\342\036\000\310\341\036\000'
  _MSGSWAPREQUEST.fields_by_name['amount']._options = None
  _MSGSWAPREQUEST.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGSWAPREQUEST._serialized_start=71
  _MSGSWAPREQUEST._serialized_end=199
  _MSGSWAPRESPONSE._serialized_start=201
  _MSGSWAPRESPONSE._serialized_end=218
  _MSGSERVICE._serialized_start=220
  _MSGSERVICE._serialized_end=312
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.subscription.v1 import quota_pb2 as sentinel_dot_subscription_dot_v1_dot_quota__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.subscription.v1 import subscription_pb2 as sentinel_dot_subscription_dot_v1_dot_subscription__pb2
from sentinel.subscription.v1 import params_pb2 as sentinel_dot_subscription_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sentinel/subscription/v1/querier.proto\x12\x18sentinel.subscription.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$sentinel/subscription/v1/quota.proto\x1a\x1esentinel/types/v1/status.proto\x1a+sentinel/subscription/v1/subscription.proto\x1a%sentinel/subscription/v1/params.proto\"W\n\x19QuerySubscriptionsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9d\x01\n#QuerySubscriptionsForAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"&\n\x18QuerySubscriptionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"0\n\x11QueryQuotaRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"\\\n\x12QueryQuotasRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x14\n\x12QueryParamsRequest\"\x9e\x01\n\x1aQuerySubscriptionsResponse\x12\x43\n\rsubscriptions\x18\x01 \x03(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xa8\x01\n$QuerySubscriptionsForAddressResponse\x12\x43\n\rsubscriptions\x18\x01 \x03(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"_\n\x19QuerySubscriptionResponse\x12\x42\n\x0csubscription\x18\x01 \x01(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\x04\xc8\xde\x1f\x00\"J\n\x12QueryQuotaResponse\x12\x34\n\x05quota\x18\x01 \x01(\x0b\x32\x1f.sentinel.subscription.v1.QuotaB\x04\xc8\xde\x1f\x00\"\x89\x01\n\x13QueryQuotasResponse\x12\x35\n\x06quotas\x18\x01 \x03(\x0b\x32\x1f.sentinel.subscription.v1.QuotaB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .sentinel.subscription.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\x81\x08\n\x0cQueryService\x12\xa0\x01\n\x12QuerySubscriptions\x12\x33.sentinel.subscription.v1.QuerySubscriptionsRequest\x1a\x34.sentinel.subscription.v1.QuerySubscriptionsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/subscriptions\x12\xd1\x01\n\x1cQuerySubscriptionsForAddress\x12=.sentinel.subscription.v1.QuerySubscriptionsForAddressRequest\x1a>.sentinel.subscription.v1.QuerySubscriptionsForAddressResponse\"2\x82\xd3\xe4\x93\x02,\x12*/sentinel/accounts/{address}/subscriptions\x12\xa2\x01\n\x11QuerySubscription\x12\x32.sentinel.subscription.v1.QuerySubscriptionRequest\x1a\x33.sentinel.subscription.v1.QuerySubscriptionResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/sentinel/subscriptions/{id}\x12\x9e\x01\n\nQueryQuota\x12+.sentinel.subscription.v1.QueryQuotaRequest\x1a,.sentinel.subscription.v1.QueryQuotaResponse\"5\x82\xd3\xe4\x93\x02/\x12-/accounts/{address}/subscriptions/{id}/quotas\x12\x97\x01\n\x0bQueryQuotas\x12,.sentinel.subscription.v1.QueryQuotasRequest\x1a-.sentinel.subscription.v1.QueryQuotasResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/subscriptions/{id}/quotas\x12\x99\x01\n\x0bQueryParams\x12,.sentinel.subscription.v1.QueryParamsRequest\x1a-.sentinel.subscription.v1.QueryParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/modules/subscription/paramsB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _QUERYSUBSCRIPTIONSRESPONSE.fields_by_name['subscriptions']._options = None
  _QUERYSUBSCRIPTIONSRESPONSE.fields_by_name['subscriptions']._serialized_options = b'\310\336\037\000'
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE.fields_by_name['subscriptions']._options = None
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE.fields_by_name['subscriptions']._serialized_options = b'\310\336\037\000'
  _QUERYSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._options = None
  _QUERYSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._serialized_options = b'\310\336\037\000'
  _QUERYQUOTARESPONSE.fields_by_name['quota']._options = None
  _QUERYQUOTARESPONSE.fields_by_name['quota']._serialized_options = b'\310\336\037\000'
  _QUERYQUOTASRESPONSE.fields_by_name['quotas']._options = None
  _QUERYQUOTASRESPONSE.fields_by_name['quotas']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QuerySubscriptions']._options = None
  _QUERYSERVICE.methods_by_name['QuerySubscriptions']._serialized_options = b'\202\323\344\223\002\031\022\027/sentinel/subscriptions'
  _QUERYSERVICE.methods_by_name['QuerySubscriptionsForAddress']._options = None
  _QUERYSERVICE.methods_by_name['QuerySubscriptionsForAddress']._serialized_options = b'\202\323\344\223\002,\022*/sentinel/accounts/{address}/subscriptions'
  _QUERYSERVICE.methods_by_name['QuerySubscription']._options = None
  _QUERYSERVICE.methods_by_name['QuerySubscription']._serialized_options = b'\202\323\344\223\002\036\022\034/sentinel/subscriptions/{id}'
  _QUERYSERVICE.methods_by_name['QueryQuota']._options = None
  _QUERYSERVICE.methods_by_name['QueryQuota']._serialized_options = b'\202\323\344\223\002/\022-/accounts/{address}/subscriptions/{id}/quotas'
  _QUERYSERVICE.methods_by_name['QueryQuotas']._options = None
  _QUERYSERVICE.methods_by_name['QueryQuotas']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/subscriptions/{id}/quotas'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\'\022%/sentinel/modules/subscription/params'
  _QUERYSUBSCRIPTIONSREQUEST._serialized_start=318
  _QUERYSUBSCRIPTIONSREQUEST._serialized_end=405
  _QUERYSUBSCRIPTIONSFORADDRESSREQUEST._serialized_start=408
  _QUERYSUBSCRIPTIONSFORADDRESSREQUEST._serialized_end=565
  _QUERYSUBSCRIPTIONREQUEST._serialized_start=567
  _QUERYSUBSCRIPTIONREQUEST._serialized_end=605
  _QUERYQUOTAREQUEST._serialized_start=607
  _QUERYQUOTAREQUEST._serialized_end=655
  _QUERYQUOTASREQUEST._serialized_start=657
  _QUERYQUOTASREQUEST._serialized_end=749
  _QUERYPARAMSREQUEST._serialized_start=751
  _QUERYPARAMSREQUEST._serialized_end=771
  _QUERYSUBSCRIPTIONSRESPONSE._serialized_start=774
  _QUERYSUBSCRIPTIONSRESPONSE._serialized_end=932
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE._serialized_start=935
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE._serialized_end=1103
  _QUERYSUBSCRIPTIONRESPONSE._serialized_start=1105
  _QUERYSUBSCRIPTIONRESPONSE._serialized_end=1200
  _QUERYQUOTARESPONSE._serialized_start=1202
  _QUERYQUOTARESPONSE._serialized_end=1276
  _QUERYQUOTASRESPONSE._serialized_start=1279
  _QUERYQUOTASRESPONSE._serialized_end=1416
  _QUERYPARAMSRESPONSE._serialized_start=1418
  _QUERYPARAMSRESPONSE._serialized_end=1495
  _QUERYSERVICE._serialized_start=1498
  _QUERYSERVICE._serialized_end=2523
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgAddQuotaRequest(_message.Message):
    __slots__ = ["address", "bytes", "frm", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    bytes: str
    frm: str
    id: int
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., address: _Optional[str] = ..., bytes: _Optional[str] = ...) -> None: ...

class MsgAddQuotaResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgCancelRequest(_message.Message):
    __slots__ = ["frm", "id"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ...) -> None: ...

class MsgCancelResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgSubscribeToNodeRequest(_message.Message):
    __slots__ = ["address", "deposit", "frm"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    address: str
    deposit: _coin_pb2.Coin
    frm: str
    def __init__(self, frm: _Optional[str] = ..., address: _Optional[str] = ..., deposit: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class MsgSubscribeToNodeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgSubscribeToPlanRequest(_message.Message):
    __slots__ = ["denom", "frm", "id"]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    denom: str
    frm: str
    id: int
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., denom: _Optional[str] = ...) -> None: ...

class MsgSubscribeToPlanResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateQuotaRequest(_message.Message):
    __slots__ = ["address", "bytes", "frm", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    bytes: str
    frm: str
    id: int
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., address: _Optional[str] = ..., bytes: _Optional[str] = ...) -> None: ...

class MsgUpdateQuotaResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/provider/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/provider/v1/msg.proto\x12\x14sentinel.provider.v1\x1a\x14gogoproto/gogo.proto\"g\n\x12MsgRegisterRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"e\n\x10MsgUpdateRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\x15\n\x13MsgRegisterResponse\"\x13\n\x11MsgUpdateResponse2\xce\x01\n\nMsgService\x12\x62\n\x0bMsgRegister\x12(.sentinel.provider.v1.MsgRegisterRequest\x1a).sentinel.provider.v1.MsgRegisterResponse\x12\\\n\tMsgUpdate\x12&.sentinel.provider.v1.MsgUpdateRequest\x1a\'.sentinel.provider.v1.MsgUpdateResponseB;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\250\342\036\000\310\341\036\000'
  _MSGREGISTERREQUEST._serialized_start=78
  _MSGREGISTERREQUEST._serialized_end=181
  _MSGUPDATEREQUEST._serialized_start=183
  _MSGUPDATEREQUEST._serialized_end=284
  _MSGREGISTERRESPONSE._serialized_start=286
  _MSGREGISTERRESPONSE._serialized_end=307
  _MSGUPDATERESPONSE._serialized_start=309
  _MSGUPDATERESPONSE._serialized_end=328
  _MSGSERVICE._serialized_start=331
  _MSGSERVICE._serialized_end=537
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interchain_security/ccv/consumer/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/interchain_security/ccv/consumer/v1/query.proto\x12#interchain_security.ccv.consumer.v1\x1a\x1cgoogle/api/annotations.proto\"\xb2\x01\n\x1bNextFeeDistributionEstimate\x12\x15\n\rcurrentHeight\x18\x01 \x01(\x03\x12\x12\n\nlastHeight\x18\x02 \x01(\x03\x12\x12\n\nnextHeight\x18\x03 \x01(\x03\x12\x1d\n\x15\x64istribution_fraction\x18\x04 \x01(\t\x12\r\n\x05total\x18\x05 \x01(\t\x12\x12\n\ntoProvider\x18\x06 \x01(\t\x12\x12\n\ntoConsumer\x18\x07 \x01(\t\")\n\'QueryNextFeeDistributionEstimateRequest\"z\n(QueryNextFeeDistributionEstimateResponse\x12N\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32@.interchain_security.ccv.consumer.v1.NextFeeDistributionEstimate2\x82\x02\n\x05Query\x12\xf8\x01\n\x18QueryNextFeeDistribution\x12L.interchain_security.ccv.consumer.v1.QueryNextFeeDistributionEstimateRequest\x1aM.interchain_security.ccv.consumer.v1.QueryNextFeeDistributionEstimateResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/interchain_security/ccv/consumer/next-fee-distributionB<Z:github.com/cosmos/interchain-security/x/ccv/consumer/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interchain_security.ccv.consumer.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/cosmos/interchain-security/x/ccv/consumer/types'
  _QUERY.methods_by_name['QueryNextFeeDistribution']._options = None
  _QUERY.methods_by_name['QueryNextFeeDistribution']._serialized_options = b'\202\323\344\223\0029\0227/interchain_security/ccv/consumer/next-fee-distribution'
  _NEXTFEEDISTRIBUTIONESTIMATE._serialized_start=119
  _NEXTFEEDISTRIBUTIONESTIMATE._serialized_end=297
  _QUERYNEXTFEEDISTRIBUTIONESTIMATEREQUEST._serialized_start=299
  _QUERYNEXTFEEDISTRIBUTIONESTIMATEREQUEST._serialized_end=340
  _QUERYNEXTFEEDISTRIBUTIONESTIMATERESPONSE._serialized_start=342
  _QUERYNEXTFEEDISTRIBUTIONESTIMATERESPONSE._serialized_end=464
  _QUERY._serialized_start=467
  _QUERY._serialized_end=725
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v1/params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/node/v1/params.proto\x12\x10sentinel.node.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x81\x03\n\x06Params\x12\x30\n\x07\x64\x65posit\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12>\n\x11inactive_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12^\n\tmax_price\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12^\n\tmin_price\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x45\n\rstaking_share\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42\x37Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v1.params_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _PARAMS.fields_by_name['deposit']._options = None
  _PARAMS.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _PARAMS.fields_by_name['inactive_duration']._options = None
  _PARAMS.fields_by_name['inactive_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _PARAMS.fields_by_name['max_price']._options = None
  _PARAMS.fields_by_name['max_price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _PARAMS.fields_by_name['min_price']._options = None
  _PARAMS.fields_by_name['min_price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _PARAMS.fields_by_name['staking_share']._options = None
  _PARAMS.fields_by_name['staking_share']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._serialized_start=138
  _PARAMS._serialized_end=523
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Quota(_message.Message):
    __slots__ = ["address", "allocated", "consumed"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ALLOCATED_FIELD_NUMBER: _ClassVar[int]
    CONSUMED_FIELD_NUMBER: _ClassVar[int]
    address: str
    allocated: str
    consumed: str
    def __init__(self, address: _Optional[str] = ..., allocated: _Optional[str] = ..., consumed: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>ibc/applications/interchain_accounts/controller/v1/query.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x1cgoogle/api/annotations.proto\"\x14\n\x12QueryParamsRequest\"a\n\x13QueryParamsResponse\x12J\n\x06params\x18\x01 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.Params2\xdf\x01\n\x05Query\x12\xd5\x01\n\x06Params\x12\x46.ibc.applications.interchain_accounts.controller.v1.QueryParamsRequest\x1aG.ibc.applications.interchain_accounts.controller.v1.QueryParamsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/ibc/apps/interchain_accounts/controller/v1/paramsBRZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/types'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\0024\0222/ibc/apps/interchain_accounts/controller/v1/params'
  _QUERYPARAMSREQUEST._serialized_start=217
  _QUERYPARAMSREQUEST._serialized_end=237
  _QUERYPARAMSRESPONSE._serialized_start=239
  _QUERYPARAMSRESPONSE._serialized_end=336
  _QUERY._serialized_start=339
  _QUERY._serialized_end=562
# @@protoc_insertion_point(module_scope)



from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



from google.api import annotations_pb2 as _annotations_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgAssignConsumerKey(_message.Message):
    __slots__ = ["chain_id", "consumer_key", "provider_addr"]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_KEY_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_ADDR_FIELD_NUMBER: _ClassVar[int]
    chain_id: str
    consumer_key: _any_pb2.Any
    provider_addr: str
    def __init__(self, chain_id: _Optional[str] = ..., provider_addr: _Optional[str] = ..., consumer_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class MsgAssignConsumerKeyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/types/v1/bandwidth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/types/v1/bandwidth.proto\x12\x11sentinel.types.v1\x1a\x14gogoproto/gogo.proto\"\x8d\x01\n\tBandwidth\x12>\n\x06upload\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12@\n\x08\x64ownload\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x42\x30Z&github.com/sentinel-official/hub/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.types.v1.bandwidth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/sentinel-official/hub/types\250\342\036\000\310\341\036\000'
  _BANDWIDTH.fields_by_name['upload']._options = None
  _BANDWIDTH.fields_by_name['upload']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _BANDWIDTH.fields_by_name['download']._options = None
  _BANDWIDTH.fields_by_name['download']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _BANDWIDTH._serialized_start=79
  _BANDWIDTH._serialized_end=220
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/provider/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.provider.v1 import provider_pb2 as sentinel_dot_provider_dot_v1_dot_provider__pb2
from sentinel.provider.v1 import params_pb2 as sentinel_dot_provider_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sentinel/provider/v1/querier.proto\x12\x14sentinel.provider.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a#sentinel/provider/v1/provider.proto\x1a!sentinel/provider/v1/params.proto\"S\n\x15QueryProvidersRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\'\n\x14QueryProviderRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x14\n\x12QueryParamsRequest\"\x8e\x01\n\x16QueryProvidersResponse\x12\x37\n\tproviders\x18\x01 \x03(\x0b\x32\x1e.sentinel.provider.v1.ProviderB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"O\n\x15QueryProviderResponse\x12\x36\n\x08provider\x18\x01 \x01(\x0b\x32\x1e.sentinel.provider.v1.ProviderB\x04\xc8\xde\x1f\x00\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x1c.sentinel.provider.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\xbb\x03\n\x0cQueryService\x12\x88\x01\n\x0eQueryProviders\x12+.sentinel.provider.v1.QueryProvidersRequest\x1a,.sentinel.provider.v1.QueryProvidersResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/sentinel/providers\x12\x8f\x01\n\rQueryProvider\x12*.sentinel.provider.v1.QueryProviderRequest\x1a+.sentinel.provider.v1.QueryProviderResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/providers/{address}\x12\x8d\x01\n\x0bQueryParams\x12(.sentinel.provider.v1.QueryParamsRequest\x1a).sentinel.provider.v1.QueryParamsResponse\")\x82\xd3\xe4\x93\x02#\x12!/sentinel/modules/provider/paramsB;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\250\342\036\000\310\341\036\000'
  _QUERYPROVIDERSRESPONSE.fields_by_name['providers']._options = None
  _QUERYPROVIDERSRESPONSE.fields_by_name['providers']._serialized_options = b'\310\336\037\000'
  _QUERYPROVIDERRESPONSE.fields_by_name['provider']._options = None
  _QUERYPROVIDERRESPONSE.fields_by_name['provider']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryProviders']._options = None
  _QUERYSERVICE.methods_by_name['QueryProviders']._serialized_options = b'\202\323\344\223\002\025\022\023/sentinel/providers'
  _QUERYSERVICE.methods_by_name['QueryProvider']._options = None
  _QUERYSERVICE.methods_by_name['QueryProvider']._serialized_options = b'\202\323\344\223\002\037\022\035/sentinel/providers/{address}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002#\022!/sentinel/modules/provider/params'
  _QUERYPROVIDERSREQUEST._serialized_start=228
  _QUERYPROVIDERSREQUEST._serialized_end=311
  _QUERYPROVIDERREQUEST._serialized_start=313
  _QUERYPROVIDERREQUEST._serialized_end=352
  _QUERYPARAMSREQUEST._serialized_start=354
  _QUERYPARAMSREQUEST._serialized_end=374
  _QUERYPROVIDERSRESPONSE._serialized_start=377
  _QUERYPROVIDERSRESPONSE._serialized_end=519
  _QUERYPROVIDERRESPONSE._serialized_start=521
  _QUERYPROVIDERRESPONSE._serialized_end=600
  _QUERYPARAMSRESPONSE._serialized_start=602
  _QUERYPARAMSRESPONSE._serialized_end=675
  _QUERYSERVICE._serialized_start=678
  _QUERYSERVICE._serialized_end=1121
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.session.v1 import session_pb2 as sentinel_dot_session_dot_v1_dot_session__pb2
from sentinel.session.v1 import params_pb2 as sentinel_dot_session_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/session/v1/querier.proto\x12\x13sentinel.session.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a!sentinel/session/v1/session.proto\x1a sentinel/session/v1/params.proto\"R\n\x14QuerySessionsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x98\x01\n\x1eQuerySessionsForAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"!\n\x13QuerySessionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"\x14\n\x12QueryParamsRequest\"\x8a\x01\n\x15QuerySessionsResponse\x12\x34\n\x08sessions\x18\x01 \x03(\x0b\x32\x1c.sentinel.session.v1.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x94\x01\n\x1fQuerySessionsForAddressResponse\x12\x34\n\x08sessions\x18\x01 \x03(\x0b\x32\x1c.sentinel.session.v1.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"K\n\x14QuerySessionResponse\x12\x33\n\x07session\x18\x01 \x01(\x0b\x32\x1c.sentinel.session.v1.SessionB\x04\xc8\xde\x1f\x00\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.sentinel.session.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\xdd\x04\n\x0cQueryService\x12\x82\x01\n\rQuerySessions\x12).sentinel.session.v1.QuerySessionsRequest\x1a*.sentinel.session.v1.QuerySessionsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/sentinel/sessions\x12\xb3\x01\n\x17QuerySessionsForAddress\x12\x33.sentinel.session.v1.QuerySessionsForAddressRequest\x1a\x34.sentinel.session.v1.QuerySessionsForAddressResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/accounts/{address}/sessions\x12\x84\x01\n\x0cQuerySession\x12(.sentinel.session.v1.QuerySessionRequest\x1a).sentinel.session.v1.QuerySessionResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/sessions/{id}\x12\x8a\x01\n\x0bQueryParams\x12\'.sentinel.session.v1.QueryParamsRequest\x1a(.sentinel.session.v1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /sentinel/modules/session/paramsB:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _QUERYSESSIONSRESPONSE.fields_by_name['sessions']._options = None
  _QUERYSESSIONSRESPONSE.fields_by_name['sessions']._serialized_options = b'\310\336\037\000'
  _QUERYSESSIONSFORADDRESSRESPONSE.fields_by_name['sessions']._options = None
  _QUERYSESSIONSFORADDRESSRESPONSE.fields_by_name['sessions']._serialized_options = b'\310\336\037\000'
  _QUERYSESSIONRESPONSE.fields_by_name['session']._options = None
  _QUERYSESSIONRESPONSE.fields_by_name['session']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QuerySessions']._options = None
  _QUERYSERVICE.methods_by_name['QuerySessions']._serialized_options = b'\202\323\344\223\002\024\022\022/sentinel/sessions'
  _QUERYSERVICE.methods_by_name['QuerySessionsForAddress']._options = None
  _QUERYSERVICE.methods_by_name['QuerySessionsForAddress']._serialized_options = b'\202\323\344\223\002\'\022%/sentinel/accounts/{address}/sessions'
  _QUERYSERVICE.methods_by_name['QuerySession']._options = None
  _QUERYSERVICE.methods_by_name['QuerySession']._serialized_options = b'\202\323\344\223\002\031\022\027/sentinel/sessions/{id}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\"\022 /sentinel/modules/session/params'
  _QUERYSESSIONSREQUEST._serialized_start=255
  _QUERYSESSIONSREQUEST._serialized_end=337
  _QUERYSESSIONSFORADDRESSREQUEST._serialized_start=340
  _QUERYSESSIONSFORADDRESSREQUEST._serialized_end=492
  _QUERYSESSIONREQUEST._serialized_start=494
  _QUERYSESSIONREQUEST._serialized_end=527
  _QUERYPARAMSREQUEST._serialized_start=529
  _QUERYPARAMSREQUEST._serialized_end=549
  _QUERYSESSIONSRESPONSE._serialized_start=552
  _QUERYSESSIONSRESPONSE._serialized_end=690
  _QUERYSESSIONSFORADDRESSRESPONSE._serialized_start=693
  _QUERYSESSIONSFORADDRESSRESPONSE._serialized_end=841
  _QUERYSESSIONRESPONSE._serialized_start=843
  _QUERYSESSIONRESPONSE._serialized_end=918
  _QUERYPARAMSRESPONSE._serialized_start=920
  _QUERYPARAMSRESPONSE._serialized_end=992
  _QUERYSERVICE._serialized_start=995
  _QUERYSERVICE._serialized_end=1600
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ["approve_by", "swap_denom", "swap_enabled"]
    APPROVE_BY_FIELD_NUMBER: _ClassVar[int]
    SWAP_DENOM_FIELD_NUMBER: _ClassVar[int]
    SWAP_ENABLED_FIELD_NUMBER: _ClassVar[int]
    approve_by: str
    swap_denom: str
    swap_enabled: bool
    def __init__(self, swap_enabled: bool = ..., swap_denom: _Optional[str] = ..., approve_by: _Optional[str] = ...) -> None: ...



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgAddNodeRequest(_message.Message):
    __slots__ = ["address", "frm", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    frm: str
    id: int
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...

class MsgAddNodeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgAddRequest(_message.Message):
    __slots__ = ["bytes", "frm", "price", "validity"]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    VALIDITY_FIELD_NUMBER: _ClassVar[int]
    bytes: str
    frm: str
    price: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    validity: _duration_pb2.Duration
    def __init__(self, frm: _Optional[str] = ..., price: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., validity: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., bytes: _Optional[str] = ...) -> None: ...

class MsgAddResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgRemoveNodeRequest(_message.Message):
    __slots__ = ["address", "frm", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    frm: str
    id: int
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...

class MsgRemoveNodeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgSetStatusRequest(_message.Message):
    __slots__ = ["frm", "id", "status"]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    status: _status_pb2.Status
    def __init__(self, frm: _Optional[str] = ..., id: _Optional[int] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ...) -> None: ...

class MsgSetStatusResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%sentinel/subscription/v1/events.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto\"i\n\x0e\x45ventSubscribe\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12\x1d\n\x04plan\x18\x03 \x01(\x04\x42\x0f\xf2\xde\x1f\x0byaml:\"plan\"\"i\n\x0e\x45ventSetStatus\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12<\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:\"status\"\"O\n\rEventAddQuota\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12#\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\"R\n\x10\x45ventUpdateQuota\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12#\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _EVENTSUBSCRIBE.fields_by_name['id']._options = None
  _EVENTSUBSCRIBE.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSUBSCRIBE.fields_by_name['node']._options = None
  _EVENTSUBSCRIBE.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTSUBSCRIBE.fields_by_name['plan']._options = None
  _EVENTSUBSCRIBE.fields_by_name['plan']._serialized_options = b'\362\336\037\013yaml:\"plan\"'
  _EVENTSETSTATUS.fields_by_name['id']._options = None
  _EVENTSETSTATUS.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSETSTATUS.fields_by_name['status']._options = None
  _EVENTSETSTATUS.fields_by_name['status']._serialized_options = b'\362\336\037\ryaml:\"status\"'
  _EVENTADDQUOTA.fields_by_name['id']._options = None
  _EVENTADDQUOTA.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTADDQUOTA.fields_by_name['address']._options = None
  _EVENTADDQUOTA.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTUPDATEQUOTA.fields_by_name['id']._options = None
  _EVENTUPDATEQUOTA.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTUPDATEQUOTA.fields_by_name['address']._options = None
  _EVENTUPDATEQUOTA.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTSUBSCRIBE._serialized_start=121
  _EVENTSUBSCRIBE._serialized_end=226
  _EVENTSETSTATUS._serialized_start=228
  _EVENTSETSTATUS._serialized_end=333
  _EVENTADDQUOTA._serialized_start=335
  _EVENTADDQUOTA._serialized_end=414
  _EVENTUPDATEQUOTA._serialized_start=416
  _EVENTUPDATEQUOTA._serialized_end=498
# @@protoc_insertion_point(module_scope)



import cosmospy_protobuf.cosmos.staking.v1beta1.query_pb2 as query_pb2
import cosmospy_protobuf.cosmos.staking.v1beta1.query_pb2_grpc as query_pb2_grpc
import grpc

host = "osmosis.strange.love"
port = 9090


class Staking:
    def __init__(self, c: grpc.Channel = grpc.insecure_channel(f"{host}:{port}")):
        self.stub = query_pb2_grpc.QueryStub(c)
        self._assets = {}

    @property
    def bonded(self):
        """Return bonded and unbonded funds"""
        r = self.stub.Pool(query_pb2.QueryPoolRequest())
        return {
            'bonded': int(r.pool.bonded_tokens),
            'unbonded': int(r.pool.not_bonded_tokens)
        }


print(Staking().bonded)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sentinel/subscription/v1/msg.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"k\n\x19MsgSubscribeToNodeRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"C\n\x19MsgSubscribeToPlanRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"+\n\x10MsgCancelRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\"}\n\x12MsgAddQuotaRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x80\x01\n\x15MsgUpdateQuotaRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x1c\n\x1aMsgSubscribeToNodeResponse\"\x1c\n\x1aMsgSubscribeToPlanResponse\"\x13\n\x11MsgCancelResponse\"\x15\n\x13MsgAddQuotaResponse\"\x18\n\x16MsgUpdateQuotaResponse2\xd5\x04\n\nMsgService\x12\x7f\n\x12MsgSubscribeToNode\x12\x33.sentinel.subscription.v1.MsgSubscribeToNodeRequest\x1a\x34.sentinel.subscription.v1.MsgSubscribeToNodeResponse\x12\x7f\n\x12MsgSubscribeToPlan\x12\x33.sentinel.subscription.v1.MsgSubscribeToPlanRequest\x1a\x34.sentinel.subscription.v1.MsgSubscribeToPlanResponse\x12\x64\n\tMsgCancel\x12*.sentinel.subscription.v1.MsgCancelRequest\x1a+.sentinel.subscription.v1.MsgCancelResponse\x12j\n\x0bMsgAddQuota\x12,.sentinel.subscription.v1.MsgAddQuotaRequest\x1a-.sentinel.subscription.v1.MsgAddQuotaResponse\x12s\n\x0eMsgUpdateQuota\x12/.sentinel.subscription.v1.MsgUpdateQuotaRequest\x1a\x30.sentinel.subscription.v1.MsgUpdateQuotaResponseB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _MSGSUBSCRIBETONODEREQUEST.fields_by_name['deposit']._options = None
  _MSGSUBSCRIBETONODEREQUEST.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _MSGADDQUOTAREQUEST.fields_by_name['bytes']._options = None
  _MSGADDQUOTAREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._options = None
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGSUBSCRIBETONODEREQUEST._serialized_start=118
  _MSGSUBSCRIBETONODEREQUEST._serialized_end=225
  _MSGSUBSCRIBETOPLANREQUEST._serialized_start=227
  _MSGSUBSCRIBETOPLANREQUEST._serialized_end=294
  _MSGCANCELREQUEST._serialized_start=296
  _MSGCANCELREQUEST._serialized_end=339
  _MSGADDQUOTAREQUEST._serialized_start=341
  _MSGADDQUOTAREQUEST._serialized_end=466
  _MSGUPDATEQUOTAREQUEST._serialized_start=469
  _MSGUPDATEQUOTAREQUEST._serialized_end=597
  _MSGSUBSCRIBETONODERESPONSE._serialized_start=599
  _MSGSUBSCRIBETONODERESPONSE._serialized_end=627
  _MSGSUBSCRIBETOPLANRESPONSE._serialized_start=629
  _MSGSUBSCRIBETOPLANRESPONSE._serialized_end=657
  _MSGCANCELRESPONSE._serialized_start=659
  _MSGCANCELRESPONSE._serialized_end=678
  _MSGADDQUOTARESPONSE._serialized_start=680
  _MSGADDQUOTARESPONSE._serialized_end=701
  _MSGUPDATEQUOTARESPONSE._serialized_start=703
  _MSGUPDATEQUOTARESPONSE._serialized_end=727
  _MSGSERVICE._serialized_start=730
  _MSGSERVICE._serialized_end=1327
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/plan/v1/plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsentinel/plan/v1/plan.proto\x12\x10sentinel.plan.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto\"\xda\x02\n\x04Plan\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08provider\x18\x02 \x01(\t\x12Z\n\x05price\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x35\n\x08validity\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12=\n\x05\x62ytes\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12)\n\x06status\x18\x06 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12\x37\n\tstatus_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x42\x37Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v1.plan_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\250\342\036\000\310\341\036\000'
  _PLAN.fields_by_name['price']._options = None
  _PLAN.fields_by_name['price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _PLAN.fields_by_name['validity']._options = None
  _PLAN.fields_by_name['validity']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _PLAN.fields_by_name['bytes']._options = None
  _PLAN.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _PLAN.fields_by_name['status_at']._options = None
  _PLAN.fields_by_name['status_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _PLAN._serialized_start=201
  _PLAN._serialized_end=547
# @@protoc_insertion_point(module_scope)



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from sentinel.node.v1 import node_pb2 as _node_pb2
from sentinel.node.v1 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryNodeRequest(_message.Message):
    __slots__ = ["address"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryNodeResponse(_message.Message):
    __slots__ = ["node"]
    NODE_FIELD_NUMBER: _ClassVar[int]
    node: _node_pb2.Node
    def __init__(self, node: _Optional[_Union[_node_pb2.Node, _Mapping]] = ...) -> None: ...

class QueryNodesForProviderRequest(_message.Message):
    __slots__ = ["address", "pagination", "status"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status
    def __init__(self, address: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryNodesForProviderResponse(_message.Message):
    __slots__ = ["nodes", "pagination"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, nodes: _Optional[_Iterable[_Union[_node_pb2.Node, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryNodesRequest(_message.Message):
    __slots__ = ["pagination", "status"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status
    def __init__(self, status: _Optional[_Union[_status_pb2.Status, str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryNodesResponse(_message.Message):
    __slots__ = ["nodes", "pagination"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, nodes: _Optional[_Iterable[_Union[_node_pb2.Node, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["params"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.deposit.v1 import deposit_pb2 as _deposit_pb2
from sentinel.node.v1 import genesis_pb2 as _genesis_pb2
from sentinel.plan.v1 import genesis_pb2 as _genesis_pb2_1
from sentinel.provider.v1 import genesis_pb2 as _genesis_pb2_1_1
from sentinel.session.v1 import genesis_pb2 as _genesis_pb2_1_1_1
from sentinel.subscription.v1 import genesis_pb2 as _genesis_pb2_1_1_1_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ["deposits", "nodes", "plans", "providers", "sessions", "subscriptions"]
    DEPOSITS_FIELD_NUMBER: _ClassVar[int]
    NODES_FIELD_NUMBER: _ClassVar[int]
    PLANS_FIELD_NUMBER: _ClassVar[int]
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    deposits: _containers.RepeatedCompositeFieldContainer[_deposit_pb2.Deposit]
    nodes: _genesis_pb2.GenesisState
    plans: _containers.RepeatedCompositeFieldContainer[_genesis_pb2_1.GenesisPlan]
    providers: _genesis_pb2_1_1.GenesisState
    sessions: _genesis_pb2_1_1_1.GenesisState
    subscriptions: _genesis_pb2_1_1_1_1.GenesisState
    def __init__(self, deposits: _Optional[_Iterable[_Union[_deposit_pb2.Deposit, _Mapping]]] = ..., nodes: _Optional[_Union[_genesis_pb2.GenesisState, _Mapping]] = ..., plans: _Optional[_Iterable[_Union[_genesis_pb2_1.GenesisPlan, _Mapping]]] = ..., providers: _Optional[_Union[_genesis_pb2_1_1.GenesisState, _Mapping]] = ..., sessions: _Optional[_Union[_genesis_pb2_1_1_1.GenesisState, _Mapping]] = ..., subscriptions: _Optional[_Union[_genesis_pb2_1_1_1_1.GenesisState, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v1/node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsentinel/node/v1/node.proto\x12\x10sentinel.node.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto\"\x8c\x02\n\x04Node\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12Z\n\x05price\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12!\n\nremote_url\x18\x04 \x01(\tB\r\xe2\xde\x1f\tRemoteURL\x12)\n\x06status\x18\x05 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12\x37\n\tstatus_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x42\x37Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v1.node_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _NODE.fields_by_name['price']._options = None
  _NODE.fields_by_name['price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _NODE.fields_by_name['remote_url']._options = None
  _NODE.fields_by_name['remote_url']._serialized_options = b'\342\336\037\tRemoteURL'
  _NODE.fields_by_name['status_at']._options = None
  _NODE.fields_by_name['status_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _NODE._serialized_start=169
  _NODE._serialized_end=437
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+sentinel/subscription/v1/subscription.proto\x12\x18sentinel.subscription.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto\"\x8e\x03\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04node\x18\x03 \x01(\t\x12.\n\x05price\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x30\n\x07\x64\x65posit\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04plan\x18\x06 \x01(\x04\x12\r\n\x05\x64\x65nom\x18\x07 \x01(\t\x12\x34\n\x06\x65xpiry\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12<\n\x04\x66ree\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12)\n\x06status\x18\n \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12\x37\n\tstatus_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x42?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _SUBSCRIPTION.fields_by_name['price']._options = None
  _SUBSCRIPTION.fields_by_name['price']._serialized_options = b'\310\336\037\000'
  _SUBSCRIPTION.fields_by_name['deposit']._options = None
  _SUBSCRIPTION.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _SUBSCRIPTION.fields_by_name['expiry']._options = None
  _SUBSCRIPTION.fields_by_name['expiry']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _SUBSCRIPTION.fields_by_name['free']._options = None
  _SUBSCRIPTION.fields_by_name['free']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _SUBSCRIPTION.fields_by_name['status_at']._options = None
  _SUBSCRIPTION.fields_by_name['status_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _SUBSCRIPTION._serialized_start=193
  _SUBSCRIPTION._serialized_end=591
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.mint.v1 import inflation_pb2 as _inflation_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ["inflations"]
    INFLATIONS_FIELD_NUMBER: _ClassVar[int]
    inflations: _containers.RepeatedCompositeFieldContainer[_inflation_pb2.Inflation]
    def __init__(self, inflations: _Optional[_Iterable[_Union[_inflation_pb2.Inflation, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/host/v1/host.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7ibc/applications/interchain_accounts/host/v1/host.proto\x12,ibc.applications.interchain_accounts.host.v1\x1a\x14gogoproto/gogo.proto\"j\n\x06Params\x12-\n\x0chost_enabled\x18\x01 \x01(\x08\x42\x17\xf2\xde\x1f\x13yaml:\"host_enabled\"\x12\x31\n\x0e\x61llow_messages\x18\x02 \x03(\tB\x19\xf2\xde\x1f\x15yaml:\"allow_messages\"BLZJgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/host/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.host.v1.host_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/host/types'
  _PARAMS.fields_by_name['host_enabled']._options = None
  _PARAMS.fields_by_name['host_enabled']._serialized_options = b'\362\336\037\023yaml:\"host_enabled\"'
  _PARAMS.fields_by_name['allow_messages']._options = None
  _PARAMS.fields_by_name['allow_messages']._serialized_options = b'\362\336\037\025yaml:\"allow_messages\"'
  _PARAMS._serialized_start=127
  _PARAMS._serialized_end=233
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.subscription.v1 import params_pb2 as _params_pb2
from sentinel.subscription.v1 import quota_pb2 as _quota_pb2
from sentinel.subscription.v1 import subscription_pb2 as _subscription_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ["params", "subscriptions"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    subscriptions: _containers.RepeatedCompositeFieldContainer[GenesisSubscription]
    def __init__(self, subscriptions: _Optional[_Iterable[_Union[GenesisSubscription, _Mapping]]] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class GenesisSubscription(_message.Message):
    __slots__ = ["quotas", "subscription"]
    QUOTAS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    quotas: _containers.RepeatedCompositeFieldContainer[_quota_pb2.Quota]
    subscription: _subscription_pb2.Subscription
    def __init__(self, subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ..., quotas: _Optional[_Iterable[_Union[_quota_pb2.Quota, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/swap/v1/params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/swap/v1/params.proto\x12\x10sentinel.swap.v1\x1a\x14gogoproto/gogo.proto\"F\n\x06Params\x12\x14\n\x0cswap_enabled\x18\x01 \x01(\x08\x12\x12\n\nswap_denom\x18\x02 \x01(\t\x12\x12\n\napprove_by\x18\x03 \x01(\tB7Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.params_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\250\342\036\000\310\341\036\000'
  _PARAMS._serialized_start=73
  _PARAMS._serialized_end=143
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
ORDER_NONE_UNSPECIFIED: Order
ORDER_ORDERED: Order
ORDER_UNORDERED: Order
STATE_CLOSED: State
STATE_INIT: State
STATE_OPEN: State
STATE_TRYOPEN: State
STATE_UNINITIALIZED_UNSPECIFIED: State

class Acknowledgement(_message.Message):
    __slots__ = ["error", "result"]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    error: str
    result: bytes
    def __init__(self, result: _Optional[bytes] = ..., error: _Optional[str] = ...) -> None: ...

class Channel(_message.Message):
    __slots__ = ["connection_hops", "counterparty", "ordering", "state", "version"]
    CONNECTION_HOPS_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    ORDERING_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    connection_hops: _containers.RepeatedScalarFieldContainer[str]
    counterparty: Counterparty
    ordering: Order
    state: State
    version: str
    def __init__(self, state: _Optional[_Union[State, str]] = ..., ordering: _Optional[_Union[Order, str]] = ..., counterparty: _Optional[_Union[Counterparty, _Mapping]] = ..., connection_hops: _Optional[_Iterable[str]] = ..., version: _Optional[str] = ...) -> None: ...

class Counterparty(_message.Message):
    __slots__ = ["channel_id", "port_id"]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class IdentifiedChannel(_message.Message):
    __slots__ = ["channel_id", "connection_hops", "counterparty", "ordering", "port_id", "state", "version"]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_HOPS_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    ORDERING_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    connection_hops: _containers.RepeatedScalarFieldContainer[str]
    counterparty: Counterparty
    ordering: Order
    port_id: str
    state: State
    version: str
    def __init__(self, state: _Optional[_Union[State, str]] = ..., ordering: _Optional[_Union[Order, str]] = ..., counterparty: _Optional[_Union[Counterparty, _Mapping]] = ..., connection_hops: _Optional[_Iterable[str]] = ..., version: _Optional[str] = ..., port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class Packet(_message.Message):
    __slots__ = ["data", "destination_channel", "destination_port", "sequence", "source_channel", "source_port", "timeout_height", "timeout_timestamp"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_PORT_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PORT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    destination_channel: str
    destination_port: str
    sequence: int
    source_channel: str
    source_port: str
    timeout_height: _client_pb2.Height
    timeout_timestamp: int
    def __init__(self, sequence: _Optional[int] = ..., source_port: _Optional[str] = ..., source_channel: _Optional[str] = ..., destination_port: _Optional[str] = ..., destination_channel: _Optional[str] = ..., data: _Optional[bytes] = ..., timeout_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., timeout_timestamp: _Optional[int] = ...) -> None: ...

class PacketState(_message.Message):
    __slots__ = ["channel_id", "data", "port_id", "sequence"]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    data: bytes
    port_id: str
    sequence: int
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., sequence: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Order(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/swap/v1/swap.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsentinel/swap/v1/swap.proto\x12\x10sentinel.swap.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\"Z\n\x04Swap\x12\x0f\n\x07tx_hash\x18\x01 \x01(\x0c\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x42\x37Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.swap_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\250\342\036\000\310\341\036\000'
  _SWAP.fields_by_name['amount']._options = None
  _SWAP.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _SWAP._serialized_start=103
  _SWAP._serialized_end=193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.subscription.v1 import params_pb2 as sentinel_dot_subscription_dot_v1_dot_params__pb2
from sentinel.subscription.v1 import quota_pb2 as sentinel_dot_subscription_dot_v1_dot_quota__pb2
from sentinel.subscription.v1 import subscription_pb2 as sentinel_dot_subscription_dot_v1_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sentinel/subscription/v1/genesis.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\x1a%sentinel/subscription/v1/params.proto\x1a$sentinel/subscription/v1/quota.proto\x1a+sentinel/subscription/v1/subscription.proto\"\x95\x01\n\x13GenesisSubscription\x12G\n\x0csubscription\x18\x01 \x01(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\t\xea\xde\x1f\x01_\xc8\xde\x1f\x00\x12\x35\n\x06quotas\x18\x02 \x03(\x0b\x32\x1f.sentinel.subscription.v1.QuotaB\x04\xc8\xde\x1f\x00\"\xa1\x01\n\x0cGenesisState\x12Y\n\rsubscriptions\x18\x01 \x03(\x0b\x32-.sentinel.subscription.v1.GenesisSubscriptionB\x13\xea\xde\x1f\x0b_,omitempty\xc8\xde\x1f\x00\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .sentinel.subscription.v1.ParamsB\x04\xc8\xde\x1f\x00\x42?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _GENESISSUBSCRIPTION.fields_by_name['subscription']._options = None
  _GENESISSUBSCRIPTION.fields_by_name['subscription']._serialized_options = b'\352\336\037\001_\310\336\037\000'
  _GENESISSUBSCRIPTION.fields_by_name['quotas']._options = None
  _GENESISSUBSCRIPTION.fields_by_name['quotas']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['subscriptions']._options = None
  _GENESISSTATE.fields_by_name['subscriptions']._serialized_options = b'\352\336\037\013_,omitempty\310\336\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSUBSCRIPTION._serialized_start=213
  _GENESISSUBSCRIPTION._serialized_end=362
  _GENESISSTATE._serialized_start=365
  _GENESISSTATE._serialized_end=526
# @@protoc_insertion_point(module_scope)



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventPay(_message.Message):
    __slots__ = ["amount", "id", "node", "subscription"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    amount: _coin_pb2.Coin
    id: int
    node: str
    subscription: int
    def __init__(self, id: _Optional[int] = ..., node: _Optional[str] = ..., subscription: _Optional[int] = ..., amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class EventSetStatus(_message.Message):
    __slots__ = ["id", "node", "status", "subscription"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: int
    node: str
    status: _status_pb2.Status
    subscription: int
    def __init__(self, id: _Optional[int] = ..., node: _Optional[str] = ..., subscription: _Optional[int] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ...) -> None: ...

class EventStart(_message.Message):
    __slots__ = ["id", "node", "subscription"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: int
    node: str
    subscription: int
    def __init__(self, id: _Optional[int] = ..., node: _Optional[str] = ..., subscription: _Optional[int] = ...) -> None: ...

class EventUpdate(_message.Message):
    __slots__ = ["id", "node", "subscription"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: int
    node: str
    subscription: int
    def __init__(self, id: _Optional[int] = ..., node: _Optional[str] = ..., subscription: _Optional[int] = ...) -> None: ...



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.node.v1 import node_pb2 as _node_pb2
from sentinel.plan.v1 import plan_pb2 as _plan_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryNodesForPlanRequest(_message.Message):
    __slots__ = ["id", "pagination"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryNodesForPlanResponse(_message.Message):
    __slots__ = ["nodes", "pagination"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, nodes: _Optional[_Iterable[_Union[_node_pb2.Node, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryPlanRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryPlanResponse(_message.Message):
    __slots__ = ["plan"]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    plan: _plan_pb2.Plan
    def __init__(self, plan: _Optional[_Union[_plan_pb2.Plan, _Mapping]] = ...) -> None: ...

class QueryPlansForProviderRequest(_message.Message):
    __slots__ = ["address", "pagination", "status"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status
    def __init__(self, address: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryPlansForProviderResponse(_message.Message):
    __slots__ = ["pagination", "plans"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PLANS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    plans: _containers.RepeatedCompositeFieldContainer[_plan_pb2.Plan]
    def __init__(self, plans: _Optional[_Iterable[_Union[_plan_pb2.Plan, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryPlansRequest(_message.Message):
    __slots__ = ["pagination", "status"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status
    def __init__(self, status: _Optional[_Union[_status_pb2.Status, str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryPlansResponse(_message.Message):
    __slots__ = ["pagination", "plans"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PLANS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    plans: _containers.RepeatedCompositeFieldContainer[_plan_pb2.Plan]
    def __init__(self, plans: _Optional[_Iterable[_Union[_plan_pb2.Plan, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...
